@@ -1,17 +1,17 @@
-"""Support session with Muffin framework."""
+"""Provide prometheus metrics for Muffin framework."""
 
 import time
 import typing as t
 
 from muffin import Request, Response, ResponseText
-from asgi_tools._types import Receive, Send, ASGIApp
-from muffin.plugin import BasePlugin
+from muffin.typing import Receive, Send, ASGIApp
+from muffin.plugins import BasePlugin
 from asgi_prometheus import (
     get_metrics, process_path, REQUESTS, REQUESTS_TIME, REQUESTS_IN_PROGRESS, RESPONSES, EXCEPTIONS
 )
 
 
-__version__ = "1.0.0"
+__version__ = "1.0.3"
 __project__ = "muffin-prometheus"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "MIT"
